##  Importing and Exporting Projects
Once the integration is successfully set up, you can import and export projects and initiatives between SAP Cloud ALM and SAP LeanIX. To learn more, see [Synchronizing Projects Between SAP Cloud ALM and SAP LeanIX](https://help.sap.com/docs/leanix/ea/synchronizing-projects-between-sap-cloud-alm-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to synchronize projects between SAP Cloud ALM and SAP LeanIX, including linking existing fact sheets, importing projects as new fact sheets, exporting initiatives to SAP Cloud ALM, running manual syncs, and delinking fact sheets.").
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
